searchData={"items":[{"type":"module","title":"prometheus_process_collector","doc":"Prometheus OS process collector API","ref":"prometheus_process_collector.html"},{"type":"function","title":"prometheus_process_collector.collect_metrics/2","doc":"Returns Metric list for each MetricFamily identified by `Name`.","ref":"prometheus_process_collector.html#collect_metrics/2"},{"type":"function","title":"prometheus_process_collector.collect_mf/2","doc":"Calls `Callback` for each `MetricFamily` of this collector","ref":"prometheus_process_collector.html#collect_mf/2"},{"type":"function","title":"prometheus_process_collector.deregister_cleanup/1","doc":"Deregister collector. No cleanup logic needed.","ref":"prometheus_process_collector.html#deregister_cleanup/1"},{"type":"function","title":"prometheus_process_collector.get_process_info/0","doc":"Get process info callback","ref":"prometheus_process_collector.html#get_process_info/0"},{"type":"extras","title":"Overview","doc":"# Prometheus.io Process Collector\n[![Hex.pm](https://img.shields.io/hexpm/v/prometheus_process_collector.svg?maxAge=2592000?style=plastic)](https://hex.pm/packages/prometheus_process_collector)\n[![Hex.pm](https://img.shields.io/hexpm/dt/prometheus_process_collector.svg?maxAge=2592000)](https://hex.pm/packages/prometheus_process_collector)\n[![Hex\nDocs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/prometheus_process_collector/)\n[![GitHub Actions](https://github.com/prometheus-erl/prometheus_process_collector/actions/workflows/ci.yml/badge.svg)](https://github.com/prometheus-erl/prometheus_process_collector/actions/workflows/ci.yml)\n[![Codecov](https://codecov.io/github/prometheus-erl/prometheus_process_collector/graph/badge.svg?token=G9HB5UKNIY)](https://codecov.io/github/prometheus-erl/prometheus_process_collector)\n\n\nCollector which exports the current state of process metrics including cpu, memory, file descriptor usage and native threads count as well as the process start and up times.\n\n- FreeBSD;\n- Linux - uses /proc;\n- MacOS X (expiremental).","ref":"readme.html"},{"type":"extras","title":"Installation - Overview","doc":"**Hex package note**: Because OTP strictly validates NIF version c_src was compiled with, I removed precompiled binaries from the Hex package. This means that OTP source code is needed to build this library.\n\nAlso collector needs to be registered (for example in default registry):\n\n```erlang\nprometheus_registry:register_collector(prometheus_process_collector)\n```\n\n```elixir\nrequire Prometheus.Registry\nPrometheus.Registry.register_collector(:prometheus_process_collector)\n```","ref":"readme.html#installation"},{"type":"extras","title":"Example scrape: - Overview","doc":"```\n# TYPE process_open_fds gauge\n# HELP process_open_fds Number of open file descriptors.\nprocess_open_fds 13\n# TYPE process_max_fds gauge\n# HELP process_max_fds Maximum number of open file descriptors.\nprocess_max_fds 20000\n# TYPE process_start_time_seconds gauge\n# HELP process_start_time_seconds Start time of the process since unix epoch in seconds.\nprocess_start_time_seconds 1508230997\n# TYPE process_uptime_seconds counter\n# HELP process_uptime_seconds Process uptime in seconds.\nprocess_uptime_seconds 76\n# TYPE process_threads_total gauge\n# HELP process_threads_total Process Threads count.\nprocess_threads_total 22\n# TYPE process_virtual_memory_bytes gauge\n# HELP process_virtual_memory_bytes Virtual memory size in bytes.\nprocess_virtual_memory_bytes 3015249920\n# TYPE process_resident_memory_bytes gauge\n# HELP process_resident_memory_bytes Resident memory size in bytes.\nprocess_resident_memory_bytes 1224400\n# TYPE process_cpu_seconds_total counter\n# HELP process_cpu_seconds_total Process CPU seconds total.\nprocess_cpu_seconds_total{kind=\"utime\"} 0.768\nprocess_cpu_seconds_total{kind=\"stime\"} 0.368\n# TYPE process_max_resident_memory_bytes gauge\n# HELP process_max_resident_memory_bytes Maximum resident set size used.\nprocess_max_resident_memory_bytes 50192384\n# TYPE process_noio_pagefaults_total counter\n# HELP process_noio_pagefaults_total Number of page faules serviced without any I/O activity.\nprocess_noio_pagefaults_total 16015\n# TYPE process_io_pagefaults_total counter\n# HELP process_io_pagefaults_total Number of page faults serviced that required I/O activity.\nprocess_io_pagefaults_total 0\n# TYPE process_swaps_total counter\n# HELP process_swaps_total Number of times a process was \"swapped\" out of main memory.\nprocess_swaps_total 0\n# TYPE process_disk_reads_total counter\n# HELP process_disk_reads_total Number of times the file system had to perform input.\nprocess_disk_reads_total 0\n# TYPE process_disk_writes_total counter\n# HELP process_disk_writes_total Number of times the file system had to perform output.\nprocess_disk_writes_total 80\n# TYPE process_signals_delivered_total counter\n# HELP process_signals_delivered_total Number of signals delivered.\nprocess_signals_delivered_total 0\n# TYPE process_voluntary_context_switches_total counter\n# HELP process_voluntary_context_switches_total Number of times a context switch resulted due to a process voluntarily giving up the processor.\nprocess_voluntary_context_switches_total 1131\n# TYPE process_involuntary_context_switches_total counter\n# HELP process_involuntary_context_switches_total Number of times a context switch resulted due to a higher priority process becoming runnable or because the current process exceeded its time slice.\nprocess_involuntary_context_switches_total 208\n```\n\nUsage\n-----\n\nYou can register this collector manually using `prometheus_process_collector/0,1` or use `default_collectors` env entry for `prometheus`.\n\nWith [Prometheus Plugs](https://github.com/prometheus-erl/prometheus-plugs) - just add prometheus_process_collector dependency to top-level project (i.e. [like here](https://github.com/prometheus-erl/prometheus-plugs-example/edit/master/mix.exs)).","ref":"readme.html#example-scrape"},{"type":"extras","title":"Integrations / Collectors / Instrumenters - Overview","doc":"- [Ecto collector](https://github.com/prometheus-erl/prometheus-ecto)\n - [Plugs Instrumenter/Exporter](https://github.com/prometheus-erl/prometheus-plugs)\n - [Elli middleware](https://github.com/elli-lib/elli_prometheus)\n - [Fuse plugin](https://github.com/jlouis/fuse#fuse_stats_prometheus)\n - [Phoenix instrumenter](https://github.com/prometheus-erl/prometheus-phoenix)\n - [Process Info Collector](https://github.com/prometheus-erl/prometheus_process_collector)\n - [Prometheus.erl](https://github.com/prometheus-erl/prometheus.erl)\n - [Prometheus.ex](https://github.com/prometheus-erl/prometheus.ex)\n - [RabbitMQ Exporter](https://github.com/prometheus-erl/prometheus_rabbitmq_exporter)\n\nLicense\n-----\n\nFreeBSD-specific part uses copy-modified code from standard utils (limits and procstat) or standard API in some places.\n\nMIT","ref":"readme.html#integrations-collectors-instrumenters"},{"type":"extras","title":"License","doc":"The MIT License (MIT)\n\nCopyright (c) 2016, Ilya Khaprov  .\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"proglang":"erlang","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}